Struct chord_rs_core::Node

source ·
pub struct Node { /* private fields */ }
A reference to a node in the chord ring

Implementations

source

impl Node

source

pub fn new(addr: SocketAddr) -> Self

source

pub fn addr(&self) -> SocketAddr

source

pub fn with_id(id: impl Into<NodeId>, addr: SocketAddr) -> Self

source

pub fn id(&self) -> NodeId

source

pub fn is_between_on_ring(id: u64, node1: u64, node2: u64) -> bool

Returns true if the given id is between 2 nodes on a ring

Arguments
  • id - The id to check
  • node1 - First node id
  • node2 - Second node id
Examples

Check if 10 is between 5 and 15

use chord_rs_core::Node;

let id = 10;
let node1 = 5;
let node2 = 15;

assert_eq!(Node::is_between_on_ring(id, node1, node2), true);

Check if 20 is between 15 and 5

use chord_rs_core::Node;

let id = 20;
let node1 = 15;
let node2 = 5;

assert_eq!(Node::is_between_on_ring(id, node1, node2), true);
source

pub fn is_between_on_ring_exclusive(id: u64, node1: u64, node2: u64) -> bool